@@ -6,8 +6,8 @@ from django.db.models.query import QuerySet
 from django.utils.timezone import now as tz_now
 from django.utils.translation import gettext_lazy as _lazy
 
-from ...models import ManagementCommandLog
-from .base import TransactionLoggedCommand
+from command_log.management.commands.base import TransactionLoggedCommand
+from command_log.models import ManagementCommandLog
 
 
 def logs_to_truncate() -> QuerySet:
@@ -31,7 +31,7 @@ class Command(TransactionLoggedCommand):
         "Truncate all log records that have passed their truncate_at timestamp."
     )
 
-    auto_expire = datetime.timedelta(seconds=10)
+    truncate_interval = datetime.timedelta(days=7)
 
     def do_command(self, *args: Any, **options: Any) -> Dict[str, Any]:
         logs = logs_to_truncate()
